<?php
declare(strict_types=1);

namespace Wildix\Calendar;

use Logger\Log;
use Wildix\Colleagues\Colleagues;
use Wildix\DependencyInjection\ConfigInterface;
use Wildix\DependencyInjection\Container;
use Wildix\Ejabberd;
use Wildix\Microsoft\Office365Service;

/**
 * Class DiConfig
 */
final class DiConfig implements ConfigInterface {

    public static function configure(Container $container): void {
        $container->singleton(
            CalendarService::class,
            function (Container $container) {
                $settingRepo     = $container->get(Settings::class);
                $eventRepo       = $container->get(Events::class);
                $ejabberdService = $container->get(Ejabberd::class);

                return new CalendarService($eventRepo, $settingRepo, $ejabberdService);
            }
        );

        $container->singleton(
            Settings::class,
            function () {
                return Settings::getInstance();
            }
        );

        $container->singleton(
            Events::class,
            function () {
                return Events::getInstance();
            }
        );

        $container->singleton(
            SyncEventsToJabber::class,
            function (Container $container) {
                $events     = $container->get(Events::class);
                $colleagues = $container->get(Colleagues::class);
                $jabber     = $container->get(Ejabberd::class);
                $log        = $container->get(Log::class);
                $enable     = $container->get(Office365Service::class)->isEnabledCalendarIntegration();
                $appId      = $enable ? Events::EVENT_APP_OFFICE365_OUTLOOK : Events::EVENT_APP_OUTLOOK;

                return new SyncEventsToJabber($events, $colleagues, $jabber, $log, $appId);
            }
        );
    }
}
